# 🚀 programmering.no | 🤓 matematikk.as
# - Add (legg til) element til sett

# Variabler
sett = {"bil", "tog", "sykkel"}

# Print originalt sett
print(f"Originalt sett: {sett}")

# Add et element til settet
sett.add("fly")

# Print oppdatert sett
print(f"Oppdatert sett: {sett}")
