# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på enkle, doble og tripple hermetegn

# Variabler
hermetegn_enkle     = 'Enkle hermetegn'
hermetegn_dobbel    = "Dobble hermetegn"
hermetegn_nøstet    = 'Det stod "programmering 24/7" på døren 👾'
hermetegn_trippel   = """Denne linjen
            går over
            3 linjer"""

# Print
print(hermetegn_enkle)
print(hermetegn_dobbel)
print(hermetegn_nøstet)
print(hermetegn_trippel)
