# 🚀 programmering.no | 🤓 matematikk.as
# - Supert navnesystem (cases)

# Variabler
litenStorStorStorOsv = "camelCase"
StorStorStorOsv      = "PascalCase"
liten_underscore_❤️     = "snake_case"
STOR_UNDERSCORE      = "SCREAMING_SNAKE_CASE"

# Print
print(liten_underscore_❤️)
