# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på tuple

# Variabler
tuppel = ("Nord", "Sør", "Øst", "Vest")

# Print hele tuppelen
print(tuppel)

# Print det første elementet i tuppelen
print(tuppel[0])
