# 🚀 programmering.no | 🤓 matematikk.as
# - Liten hack for å inkludere øvre grense i range

# Variabler
intervall = range(4, 10 + 1) # Øvre grense + 1

# Nå er øvre grense 10 inkludert
for tall in intervall:
    print(tall)
