# 🚀 programmering.no | 🤓 matematikk.as
# - Finn produktet av alle elementene i en liste med numpy

import numpy

# Verdier
liste = [2, 3, 10]

# Finn produktet med numpy
produkt = numpy.prod(liste)

# Print
print(f"Liste                   : {liste}")
print(f"Produktet av elementene : {produkt}")
