# 🚀 programmering.no | 🤓 matematikk.as
# S2 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 1 c) og d) Alle svar - eksamen - DEMO
# - Løser alle eksamens-oppgaver med CAS i Python (DEMO)
# - Kopier denne kommandoen i terminalen for å importere matematikk:
#   $ pip install matematikk

import matematikk as mt

alle_svar = mt.eksamen(
    p = 79 - 12.2 * mt.ln(mt.Symbol("x"))
) 

